@@ -1,6 +1,7 @@
 package ca
 
 import (
+	"context"
 	"crypto/rand"
 	"crypto/x509"
 	"fmt"
@@ -11,6 +12,7 @@ import (
 
 	"github.com/manifoldco/promptui"
 	"github.com/smallstep/certificates/cas/apiv1"
+	"github.com/smallstep/certificates/kms"
 	"github.com/smallstep/certificates/pki"
 	"github.com/smallstep/cli/command"
 	"github.com/smallstep/cli/crypto/pemutil"
@@ -18,6 +20,9 @@ import (
 	"github.com/smallstep/cli/ui"
 	"github.com/smallstep/cli/utils"
 	"github.com/urfave/cli"
+
+	// Enable azurekms
+	_ "github.com/smallstep/certificates/kms/azurekms"
 )
 
 func initCommand() cli.Command {
@@ -26,10 +31,11 @@ func initCommand() cli.Command {
 		Action: cli.ActionFunc(initAction),
 		Usage:  "initialize the CA PKI",
 		UsageText: `**step ca init**
-[**--root**=<file>] [**--key**=<file>] [**--pki**] [**--ssh**] [**--name**=<name>]
+[**--root**=<file>] [**--key**=<file>] [**--pki**] [**--ssh**]
+[**--helm**] [**--deployment-type**=<name>] [**--name**=<name>]
 [**--dns**=<dns>] [**--address**=<address>] [**--provisioner**=<name>]
 [**--provisioner-password-file**=<file>] [**--password-file**=<file>]
-[**--with-ca-url**=<url>] [**--no-db**]`,
+[**--with-ca-url**=<url>] [**--ra**=<type>] [**--kms**=<type>] [**--no-db**]`,
 		Description: `**step ca init** command initializes a public key infrastructure (PKI) to be
  used by the Certificate Authority.`,
 		Flags: []cli.Flag{
@@ -109,7 +115,14 @@ Use the '--dns' flag multiple times to configure multiple DNS names.`,
 			},
 			cli.StringFlag{
 				Name:  "ra",
-				Usage: `The registration authority <name> to use. Currently "StepCAS" and "CloudCAS" are supported.`,
+				Usage: `The registration authority <type> to use. Currently "StepCAS" and "CloudCAS" are supported.`,
+			},
+			cli.StringFlag{
+				Name: "kms",
+				Usage: `The key manager service <type> to use to manage keys. Options are:
+	**azurekms**
+    :  Use Azure Key Vault to manage X.509 and SSH keys. The key URIs have
+	the following format <azurekms:name=key-name;vault=vault-name>.`,
 			},
 			cli.StringFlag{
 				Name: "issuer",
@@ -154,7 +167,7 @@ Cloud.`,
 }
 
 func initAction(ctx *cli.Context) (err error) {
-	if err = assertCryptoRand(); err != nil {
+	if err := assertCryptoRand(); err != nil {
 		return err
 	}
 
@@ -165,16 +178,17 @@ func initAction(ctx *cli.Context) (err error) {
 	root := ctx.String("root")
 	key := ctx.String("key")
 	ra := strings.ToLower(ctx.String("ra"))
+	kmsName := strings.ToLower(ctx.String("kms"))
 	pkiOnly := ctx.Bool("pki")
 	noDB := ctx.Bool("no-db")
 	helm := ctx.Bool("helm")
 
 	switch {
-	case len(root) > 0 && len(key) == 0:
+	case root != "" && key == "":
 		return errs.RequiredWithFlag(ctx, "root", "key")
-	case len(root) == 0 && len(key) > 0:
+	case root == "" && key != "":
 		return errs.RequiredWithFlag(ctx, "key", "root")
-	case len(root) > 0 && len(key) > 0:
+	case root != "" && key != "":
 		if rootCrt, err = pemutil.ReadCertificate(root); err != nil {
 			return err
 		}
@@ -183,6 +197,10 @@ func initAction(ctx *cli.Context) (err error) {
 		}
 	case ra != "" && ra != apiv1.CloudCAS && ra != apiv1.StepCAS:
 		return errs.InvalidFlagValue(ctx, "ra", ctx.String("ra"), "StepCAS or CloudCAS")
+	case kmsName != "" && kmsName != "azurekms":
+		return errs.InvalidFlagValue(ctx, "kms", ctx.String("kms"), "azurekms")
+	case kmsName != "" && ra != "":
+		return errs.IncompatibleFlagWithFlag(ctx, "kms", "ra")
 	case pkiOnly && noDB:
 		return errs.IncompatibleFlagWithFlag(ctx, "pki", "no-db")
 	case pkiOnly && helm:
@@ -212,6 +230,7 @@ func initAction(ctx *cli.Context) (err error) {
 	var name, org, resource string
 	var casOptions apiv1.Options
 	var deploymentType pki.DeploymentType
+	var opts []pki.Option
 	switch ra {
 	case apiv1.CloudCAS:
 		var create bool
@@ -356,14 +375,71 @@ func initAction(ctx *cli.Context) (err error) {
 		if err != nil {
 			return err
 		}
-		org = name
+
+		// Get names for key managers keys.
+		// Currently only azure is supported.
+		var keyManager kms.KeyManager
+		if kmsName != "" {
+			var rootURI, intermediateURI, sshHostURI, sshUserURI string
+			keyManager, err = kms.New(context.Background(), kms.Options{
+				Type: kmsName,
+			})
+			if err != nil {
+				return err
+			}
+
+			var validateFunc func(s string) error
+			if v, ok := keyManager.(interface{ ValidateName(s string) error }); ok {
+				validateFunc = v.ValidateName
+			} else {
+				validateFunc = func(s string) error {
+					return nil
+				}
+			}
+
+			if rootKey == nil {
+				ui.Println("What URI would you like to use for the root certificate key?")
+				rootURI, err = ui.Prompt("(e.g. azurekms:name=my-root-key;vault=my-vault)", ui.WithValidateFunc(validateFunc))
+				if err != nil {
+					return err
+				}
+			}
+
+			ui.Println("What URI would you like to use for the intermediate certificate key?")
+			intermediateURI, err = ui.Prompt("(e.g. azurekms:name=my-intermediate-key;vault=my-vault)", ui.WithValidateFunc(validateFunc))
+			if err != nil {
+				return err
+			}
+
+			if ctx.Bool("ssh") {
+				ui.Println("What URI would you like to use for the SSH host key?")
+				sshHostURI, err = ui.Prompt("(e.g. azurekms:name=my-host-key;vault=my-vault)", ui.WithValidateFunc(validateFunc))
+				if err != nil {
+					return err
+				}
+
+				ui.Println("What URI would you like to use for the SSH user key?")
+				sshUserURI, err = ui.Prompt("(e.g. azurekms:name=my-user-key;vault=my-vault)", ui.WithValidateFunc(validateFunc))
+				if err != nil {
+					return err
+				}
+			}
+
+			// Add uris to the pki options. Empty URIs will be ignored.
+			opts = append(opts, pki.WithKMS(kmsName),
+				pki.WithKeyURIs(rootURI, intermediateURI, sshHostURI, sshUserURI))
+		}
+
+		// set org and resource to pki name
+		org, resource = name, name
+
 		casOptions = apiv1.Options{
-			Type:      apiv1.SoftCAS,
-			IsCreator: true,
+			Type:       apiv1.SoftCAS,
+			IsCreator:  true,
+			KeyManager: keyManager,
 		}
 	}
 
-	var opts []pki.Option
 	if pkiOnly {
 		opts = append(opts, pki.WithPKIOnly())
 	} else {
@@ -376,10 +452,10 @@ func initAction(ctx *cli.Context) (err error) {
 			dnsValidator = ui.DNS()
 			dnsNames     []string
 		)
-		dnsValue = strings.Replace(dnsValue, " ", ",", -1)
+		dnsValue = strings.ReplaceAll(dnsValue, " ", ",")
 		parts := strings.Split(dnsValue, ",")
 		for _, name := range parts {
-			if len(name) == 0 {
+			if name == "" {
 				continue
 			}
 			if err := dnsValidator(name); err != nil {
@@ -409,12 +485,12 @@ func initAction(ctx *cli.Context) (err error) {
 			}
 		}
 
-		opts = []pki.Option{
+		opts = append(opts,
 			pki.WithAddress(address),
 			pki.WithCaURL(caURL),
 			pki.WithDNSNames(dnsNames),
 			pki.WithDeploymentType(deploymentType),
-		}
+		)
 		if deploymentType == pki.StandaloneDeployment {
 			opts = append(opts, pki.WithProvisioner(provisioner))
 		}
@@ -436,7 +512,7 @@ func initAction(ctx *cli.Context) (err error) {
 		return err
 	}
 
-	if ra != "" {
+	if ra != "" || kmsName != "" {
 		// RA mode will not have encrypted keys. With the exception of SSH keys,
 		// but this is not common on RA mode.
 		ui.Println("Choose a password for your first provisioner.", ui.WithValue(password))
@@ -457,11 +533,11 @@ func initAction(ctx *cli.Context) (err error) {
 	if !pkiOnly && deploymentType == pki.StandaloneDeployment {
 		// Generate provisioner key pairs.
 		if len(provisionerPassword) > 0 {
-			if err = p.GenerateKeyPairs(provisionerPassword); err != nil {
+			if err := p.GenerateKeyPairs(provisionerPassword); err != nil {
 				return err
 			}
 		} else {
-			if err = p.GenerateKeyPairs(pass); err != nil {
+			if err := p.GenerateKeyPairs(pass); err != nil {
 				return err
 			}
 		}
@@ -481,7 +557,7 @@ func initAction(ctx *cli.Context) (err error) {
 		} else {
 			ui.Printf("Copying root certificate... ")
 			// Do not copy key in STEPPATH
-			if err = p.WriteRootCertificate(rootCrt, nil, nil); err != nil {
+			if err := p.WriteRootCertificate(rootCrt, nil, nil); err != nil {
 				return err
 			}
 			root = p.CreateCertificateAuthorityResponse(rootCrt, rootKey)
@@ -496,11 +572,9 @@ func initAction(ctx *cli.Context) (err error) {
 			return err
 		}
 		ui.Println("done!")
-	} else {
+	} else if err := p.GetCertificateAuthority(); err != nil {
 		// Attempt to get the root certificate from RA.
-		if err := p.GetCertificateAuthority(); err != nil {
-			return err
-		}
+		return err
 	}
 
 	if ctx.Bool("ssh") {
