@@ -10,10 +10,13 @@ import (
 
 func removeCommand() cli.Command {
 	return cli.Command{
-		Name:      "remove",
-		Action:    cli.ActionFunc(removeAction),
-		Usage:     "remove a provisioner from the CA configuration",
-		UsageText: `**step beta ca provisioner remove** <name> [**--ca-url**=<uri>] [**--root**=<file>]`,
+		Name:   "remove",
+		Action: cli.ActionFunc(removeAction),
+		Usage:  "remove a provisioner from the CA configuration",
+		UsageText: `**step beta ca provisioner remove** <name>
+[**--admin-cert**=<file>] [**--admin-key**=<file>]
+[**--admin-provisioner**=<string>] [**--admin-subject**=<string>]
+[**--password-file**=<file>] [**--ca-url**=<uri>] [**--root**=<file>]`,
 		Flags: []cli.Flag{
 			flags.AdminCert,
 			flags.AdminKey,
