@@ -267,7 +267,7 @@ func tokenAction(ctx *cli.Context) error {
 	}
 
 	root := ctx.String("root")
-	if len(root) == 0 {
+	if root == "" {
 		root = pki.GetRootCAPath()
 		if _, err := os.Stat(root); err != nil {
 			return errs.RequiredFlag(ctx, "root")
