@@ -194,7 +194,7 @@ func signAction(ctx *cli.Context) error {
 	kid := ctx.String("kid")
 	var isX5C bool
 	if len(x5cCertFile) > 0 {
-		if len(x5cKeyFile) == 0 {
+		if x5cKeyFile == "" {
 			return errs.RequiredWithOrFlag(ctx, "x5c-cert", "key", "x5c-key")
 		}
 		if len(x5tCertFile) > 0 {
@@ -211,7 +211,7 @@ func signAction(ctx *cli.Context) error {
 
 	var isX5T bool
 	if len(x5tCertFile) > 0 {
-		if len(x5tKeyFile) == 0 {
+		if x5tKeyFile == "" {
 			return errs.RequiredWithOrFlag(ctx, "x5t-cert", "key", "x5t-key")
 		}
 		if len(x5cCertFile) > 0 {
@@ -250,7 +250,7 @@ func signAction(ctx *cli.Context) error {
 	if isSubtle {
 		options = append(options, jose.WithSubtle(true))
 	}
-	if passwordFile := ctx.String("password-file"); len(passwordFile) != 0 {
+	if passwordFile := ctx.String("password-file"); passwordFile != "" {
 		options = append(options, jose.WithPasswordFile(passwordFile))
 	}
 
@@ -289,7 +289,7 @@ func signAction(ctx *cli.Context) error {
 	if jwk.Algorithm == "" {
 		return errors.New("flag '--alg' is required with the given key")
 	}
-	if err = jose.ValidateJWK(jwk); err != nil {
+	if err := jose.ValidateJWK(jwk); err != nil {
 		return err
 	}
 
