@@ -255,6 +255,7 @@ func oauthCmd(c *cli.Context) error {
 		Implicit:            c.Bool("implicit"),
 		CallbackListener:    c.String("listen"),
 		CallbackListenerURL: c.String("listen-url"),
+		CallbackPath:        "/",
 		TerminalRedirect:    c.String("redirect-url"),
 		Browser:             c.String("browser"),
 	}
@@ -314,7 +315,7 @@ func oauthCmd(c *cli.Context) error {
 			tokenEp = details["token_uri"].(string)
 			clientID = details["client_id"].(string)
 			clientSecret = details["client_secret"].(string)
-		} else if accountType, ok := account["type"]; ok && "service_account" == accountType {
+		} else if accountType, ok := account["type"]; ok && accountType == "service_account" {
 			authzEp = account["auth_uri"].(string)
 			tokenEp = account["token_uri"].(string)
 			clientID = account["private_key_id"].(string)
@@ -341,15 +342,16 @@ func oauthCmd(c *cli.Context) error {
 	}
 
 	var tok *token
-	if do2lo {
+	switch {
+	case do2lo:
 		if c.Bool("jwt") {
 			tok, err = o.DoJWTAuthorization(issuer, scope)
 		} else {
 			tok, err = o.DoTwoLeggedAuthorization(issuer)
 		}
-	} else if opts.Console {
+	case opts.Console:
 		tok, err = o.DoManualAuthorization()
-	} else {
+	default:
 		tok, err = o.DoLoopbackAuthorization()
 	}
 
@@ -389,6 +391,7 @@ type options struct {
 	Implicit            bool
 	CallbackListener    string
 	CallbackListenerURL string
+	CallbackPath        string
 	TerminalRedirect    string
 	Browser             string
 }
@@ -404,9 +407,13 @@ func (o *options) Validate() error {
 		}
 	}
 	if o.CallbackListenerURL != "" {
-		if u, err := url.Parse(o.CallbackListenerURL); err != nil || u.Scheme == "" {
+		u, err := url.Parse(o.CallbackListenerURL)
+		if err != nil || u.Scheme == "" {
 			return errors.Wrapf(err, "invalid value '%s' for flag '--listen-url'", o.CallbackListenerURL)
 		}
+		if u.Path != "" {
+			o.CallbackPath = u.Path
+		}
 	}
 	return nil
 }
@@ -428,13 +435,14 @@ type oauth struct {
 	implicit            bool
 	CallbackListener    string
 	CallbackListenerURL string
+	CallbackPath        string
 	terminalRedirect    string
 	browser             string
 	errCh               chan error
 	tokCh               chan *token
 }
 
-func newOauth(provider, clientID, clientSecret, authzEp, tokenEp, scope string, prompt string, opts *options) (*oauth, error) {
+func newOauth(provider, clientID, clientSecret, authzEp, tokenEp, scope, prompt string, opts *options) (*oauth, error) {
 	state, err := randutil.Alphanumeric(32)
 	if err != nil {
 		return nil, err
@@ -468,6 +476,7 @@ func newOauth(provider, clientID, clientSecret, authzEp, tokenEp, scope string,
 			implicit:            opts.Implicit,
 			CallbackListener:    opts.CallbackListener,
 			CallbackListenerURL: opts.CallbackListenerURL,
+			CallbackPath:        opts.CallbackPath,
 			terminalRedirect:    opts.TerminalRedirect,
 			browser:             opts.Browser,
 			errCh:               make(chan error),
@@ -507,6 +516,7 @@ func newOauth(provider, clientID, clientSecret, authzEp, tokenEp, scope string,
 			implicit:            opts.Implicit,
 			CallbackListener:    opts.CallbackListener,
 			CallbackListenerURL: opts.CallbackListenerURL,
+			CallbackPath:        opts.CallbackPath,
 			terminalRedirect:    opts.TerminalRedirect,
 			browser:             opts.Browser,
 			errCh:               make(chan error),
@@ -516,28 +526,28 @@ func newOauth(provider, clientID, clientSecret, authzEp, tokenEp, scope string,
 }
 
 func disco(provider string) (map[string]interface{}, error) {
-	url, err := url.Parse(provider)
+	u, err := url.Parse(provider)
 	if err != nil {
 		return nil, err
 	}
 	// TODO: OIDC and OAuth specify two different ways of constructing this
 	// URL. This is the OIDC way. Probably want to try both. See
 	// https://tools.ietf.org/html/rfc8414#section-5
-	if !strings.Contains(url.Path, "/.well-known/openid-configuration") {
-		url.Path = path.Join(url.Path, "/.well-known/openid-configuration")
+	if !strings.Contains(u.Path, "/.well-known/openid-configuration") {
+		u.Path = path.Join(u.Path, "/.well-known/openid-configuration")
 	}
-	resp, err := http.Get(url.String())
+	resp, err := http.Get(u.String())
 	if err != nil {
-		return nil, errors.Wrapf(err, "error retrieving %s", url.String())
+		return nil, errors.Wrapf(err, "error retrieving %s", u.String())
 	}
 	defer resp.Body.Close()
 	b, err := ioutil.ReadAll(resp.Body)
 	if err != nil {
-		return nil, errors.Wrapf(err, "error retrieving %s", url.String())
+		return nil, errors.Wrapf(err, "error retrieving %s", u.String())
 	}
 	details := make(map[string]interface{})
 	if err = json.Unmarshal(b, &details); err != nil {
-		return nil, errors.Wrapf(err, "error reading %s: unsupported format", url.String())
+		return nil, errors.Wrapf(err, "error reading %s: unsupported format", u.String())
 	}
 	return details, err
 }
@@ -767,7 +777,7 @@ func (o *oauth) DoJWTAuthorization(issuer, aud string) (*token, error) {
 // ServeHTTP is the handler that performs the OAuth 2.0 dance and returns the
 // tokens using channels.
 func (o *oauth) ServeHTTP(w http.ResponseWriter, req *http.Request) {
-	if req.URL.Path != "/" {
+	if req.URL.Path != o.CallbackPath {
 		http.NotFound(w, req)
 		return
 	}
