@@ -146,7 +146,7 @@ type tokenAttrs struct {
 
 func generateK8sSAToken(ctx *cli.Context, p *provisioner.K8sSA) (string, error) {
 	path := ctx.String("k8ssa-token-path")
-	if len(path) == 0 {
+	if path == "" {
 		path = "/var/run/secrets/kubernetes.io/serviceaccount/token"
 	}
 	tokBytes, err := ioutil.ReadFile(path)
@@ -159,10 +159,10 @@ func generateK8sSAToken(ctx *cli.Context, p *provisioner.K8sSA) (string, error)
 func generateX5CToken(ctx *cli.Context, p *provisioner.X5C, tokType int, tokAttrs tokenAttrs) (string, error) {
 	x5cCertFile := ctx.String("x5c-cert")
 	x5cKeyFile := ctx.String("x5c-key")
-	if len(x5cCertFile) == 0 {
+	if x5cCertFile == "" {
 		return "", errs.RequiredWithProvisionerTypeFlag(ctx, "X5C", "x5c-cert")
 	}
-	if len(x5cKeyFile) == 0 {
+	if x5cKeyFile == "" {
 		return "", errs.RequiredWithProvisionerTypeFlag(ctx, "X5C", "x5c-key")
 	}
 
@@ -197,10 +197,10 @@ func generateX5CToken(ctx *cli.Context, p *provisioner.X5C, tokType int, tokAttr
 func generateSSHPOPToken(ctx *cli.Context, p *provisioner.SSHPOP, tokType int, tokAttrs tokenAttrs) (string, error) {
 	sshPOPCertFile := ctx.String("sshpop-cert")
 	sshPOPKeyFile := ctx.String("sshpop-key")
-	if len(sshPOPCertFile) == 0 {
+	if sshPOPCertFile == "" {
 		return "", errs.RequiredWithProvisionerTypeFlag(ctx, "SSHPOP", "sshpop-cert")
 	}
-	if len(sshPOPKeyFile) == 0 {
+	if sshPOPKeyFile == "" {
 		return "", errs.RequiredWithProvisionerTypeFlag(ctx, "SSHPOP", "sshpop-key")
 	}
 
@@ -252,7 +252,7 @@ func loadJWK(ctx *cli.Context, p *provisioner.JWK, tokAttrs tokenAttrs) (jwk *jo
 		opts = append(opts, passOpt)
 	}
 
-	if keyFile := ctx.String("key"); len(keyFile) == 0 {
+	if keyFile := ctx.String("key"); keyFile == "" {
 		if p == nil {
 			return nil, "", errors.New("no provisioner selected")
 		}
@@ -261,7 +261,7 @@ func loadJWK(ctx *cli.Context, p *provisioner.JWK, tokAttrs tokenAttrs) (jwk *jo
 		var encryptedKey string
 		if ctx.IsSet("offline") {
 			encryptedKey = p.EncryptedKey
-			if len(encryptedKey) == 0 {
+			if encryptedKey == "" {
 				return nil, "", errors.Errorf("provisioner '%s' does not have an 'encryptedKey' property", kid)
 			}
 		} else {
@@ -293,11 +293,12 @@ func loadJWK(ctx *cli.Context, p *provisioner.JWK, tokAttrs tokenAttrs) (jwk *jo
 			return nil, "", err
 		}
 
-		if p != nil {
+		switch {
+		case p != nil:
 			kid = p.Key.KeyID
-		} else if len(tokAttrs.kid) > 0 {
+		case len(tokAttrs.kid) > 0:
 			kid = tokAttrs.kid
-		} else {
+		default:
 			hash, err := jwk.Thumbprint(crypto.SHA256)
 			if err != nil {
 				return nil, "", errors.Wrap(err, "error generating JWK thumbprint")
